@@ -24,22 +24,20 @@ Boston, MA 02110-1301, USA.
 #include <QSpinBox>
 #include <QCheckBox>
 #include <QString>
-#include <KDebug>
 
 #include <interfaces/isourceformatter.h>
 #include <util/formattinghelpers.h>
+
 #include "astyle_stringiterator.h"
+#include "debug.h"
+
+using namespace KDevelop;
 
 AStyleFormatter::AStyleFormatter()
 : ASFormatter()
 {
 }
 
-// AStyleFormatter::AStyleFormatter(const QMap<QString, QVariant>& options)
-// {
-//     setOptions(options);
-// }
-
 QString AStyleFormatter::formatSource(const QString &text, const QString& leftContext, const QString& rightContext)
 {
     QString useText = leftContext + text + rightContext;
@@ -55,7 +53,7 @@ QString AStyleFormatter::formatSource(const QString &text, const QString& leftCo
 
     init(0);
 
-    return KDevelop::extractFormattedTextFromContext(output, text, leftContext, rightContext, m_options["FillCount"].toInt());
+    return extractFormattedTextFromContext(output, text, leftContext, rightContext, m_options["FillCount"].toInt());
 }
 
 void AStyleFormatter::setOption(const QString &key, const QVariant &value)
@@ -63,15 +61,9 @@ void AStyleFormatter::setOption(const QString &key, const QVariant &value)
     m_options[key] = value;
 }
 
-// void AStyleFormatter::setOptions(const QMap<QString, QVariant> &options)
-// {
-//     m_options = options;
-//     updateFormatter();
-// }
-
 void AStyleFormatter::updateFormatter()
 {
-    kDebug() << "Updating option with: " << KDevelop::ISourceFormatter::optionMapToString(m_options) << endl;
+    qCDebug(ASTYLE) << "Updating option with: " << ISourceFormatter::optionMapToString(m_options) << endl;
     // fill
     int wsCount = m_options["FillCount"].toInt();
     if(m_options["Fill"].toString() == "Tabs") {
@@ -112,11 +104,11 @@ void AStyleFormatter::updateFormatter()
     else if(s == "Attach")
         AStyleFormatter::setBracketFormatMode(astyle::ATTACH_MODE);
     else if(s == "Linux")
-        AStyleFormatter::setBracketFormatMode(astyle::BDAC_MODE);
+        AStyleFormatter::setBracketFormatMode(astyle::LINUX_MODE);
     else if(s == "Stroustrup")
         AStyleFormatter::setBracketFormatMode(astyle::STROUSTRUP_MODE);
-    else if(s == "Horstmann")
-        AStyleFormatter::setBracketFormatMode(astyle::HORSTMANN_MODE);
+    else if(s == "Horstmann" || s == "RunInMode")
+        AStyleFormatter::setBracketFormatMode(astyle::RUN_IN_MODE);
     else
         AStyleFormatter::setBracketFormatMode(astyle::NONE_MODE);
 
@@ -130,6 +122,7 @@ void AStyleFormatter::updateFormatter()
     AStyleFormatter::setOperatorPaddingMode(m_options["PadOperators"].toBool());
     AStyleFormatter::setParensInsidePaddingMode(m_options["PadParenthesesIn"].toBool());
     AStyleFormatter::setParensOutsidePaddingMode(m_options["PadParenthesesOut"].toBool());
+    AStyleFormatter::setParensHeaderPaddingMode(m_options["PadParenthesesHeader"].toBool());
     AStyleFormatter::setParensUnPaddingMode(m_options["PadParenthesesUn"].toBool());
 
     // oneliner
@@ -139,13 +132,13 @@ void AStyleFormatter::updateFormatter()
     // pointer
     s = m_options["PointerAlign"].toString();
     if(s == "Name")
-        AStyleFormatter::setPointerAlignment(astyle::ALIGN_NAME);
+        AStyleFormatter::setPointerAlignment(astyle::PTR_ALIGN_NAME);
     else if(s == "Middle")
-        AStyleFormatter::setPointerAlignment(astyle::ALIGN_MIDDLE);
+        AStyleFormatter::setPointerAlignment(astyle::PTR_ALIGN_MIDDLE);
     else if(s == "Type")
-        AStyleFormatter::setPointerAlignment(astyle::ALIGN_TYPE);
+        AStyleFormatter::setPointerAlignment(astyle::PTR_ALIGN_TYPE);
     else
-        AStyleFormatter::setPointerAlignment(astyle::ALIGN_NONE);
+        AStyleFormatter::setPointerAlignment(astyle::PTR_ALIGN_NONE);
 }
 
 void AStyleFormatter::resetStyle()
@@ -176,6 +169,7 @@ void AStyleFormatter::resetStyle()
     setOperatorPaddingMode(false);
     setParensInsidePaddingMode(true);
     setParensOutsidePaddingMode(true);
+    setParensHeaderPaddingMode(true);
     setParensUnPaddingMode(true);
 }
 
@@ -203,7 +197,7 @@ bool AStyleFormatter::predefinedStyle( const QString & style )
         resetStyle();
         setBracketIndent(false);
         setSpaceIndentation(8);
-        setBracketFormatMode(astyle::BDAC_MODE);
+        setBracketFormatMode(astyle::LINUX_MODE);
         setClassIndent(false);
         setSwitchIndent(false);
         setNamespaceIndent(false);
@@ -230,30 +224,18 @@ bool AStyleFormatter::predefinedStyle( const QString & style )
         setBracketFormatMode(astyle::STROUSTRUP_MODE);
         setBlockIndent(false);
         setBracketIndent(false);
-        if (!getIndentManuallySet())
-        {
-            if (getIndentString() == "\t")
-                setTabIndentation(5, getForceTabIndentation());
-            else
-                setSpaceIndentation(5);
-        }
+        setSpaceIndentation(5);
         setClassIndent(false);
         setSwitchIndent(false);
         setNamespaceIndent(false);
         return true;
     } else if (style == "Horstmann") {
         resetStyle();
-        setBracketFormatMode(astyle::HORSTMANN_MODE);
+        setBracketFormatMode(astyle::RUN_IN_MODE);
         setBlockIndent(false);
         setBracketIndent(false);
         setSwitchIndent(true);
-        if (!getIndentManuallySet())
-        {
-            if (getIndentString() == "\t")
-                setTabIndentation(3, getForceTabIndentation());
-            else
-                setSpaceIndentation(3);
-        }
+        setSpaceIndentation(3);
         setClassIndent(false);
         setNamespaceIndent(false);
         return true;
@@ -289,14 +271,16 @@ bool AStyleFormatter::predefinedStyle( const QString & style )
         setNamespaceIndent(false);
         return true;
     } else if (style == "KDELibs") {
+        // http://techbase.kde.org/Policies/Kdelibs_Coding_Style
         resetStyle();
         setSpaceIndentation(4);
         setBracketFormatMode(astyle::LINUX_MODE);
-        setPointerAlignment(astyle::ALIGN_TYPE);
+        setPointerAlignment(astyle::PTR_ALIGN_TYPE);
         setLabelIndent(true);
         setOperatorPaddingMode(true);
         setParensInsidePaddingMode(false);
-        setParensOutsidePaddingMode(true);
+        setParensOutsidePaddingMode(false);
+        setParensHeaderPaddingMode(true);
         setParensUnPaddingMode(true);
         setSingleStatementsMode(false);
         setTabSpaceConversionMode(true);
@@ -306,13 +290,15 @@ bool AStyleFormatter::predefinedStyle( const QString & style )
         setNamespaceIndent(false);
         return true;
     } else if (style == "Qt") {
+        // http://qt-project.org/wiki/Qt_Coding_Style
         resetStyle();
-        setPointerAlignment(astyle::ALIGN_NAME);
+        setPointerAlignment(astyle::PTR_ALIGN_NAME);
         setOperatorPaddingMode(true);
         setBracketFormatMode(astyle::LINUX_MODE);
         setSwitchIndent(false);
         setParensInsidePaddingMode(false);
         setParensOutsidePaddingMode(false);
+        setParensHeaderPaddingMode(true);
         setParensUnPaddingMode(true);
         setSpaceIndentation(4);
         setClassIndent(false);
@@ -326,7 +312,7 @@ bool AStyleFormatter::predefinedStyle( const QString & style )
 QVariant AStyleFormatter::option(const QString &key)
 {
     if(!m_options.contains(key))
-        kDebug() << "Missing option name " << key << endl;
+        qCDebug(ASTYLE) << "Missing option name " << key << endl;
     return m_options[key];
 }
 
@@ -335,43 +321,15 @@ QString AStyleFormatter::indentString()
     return QString(getIndentString().c_str());
 }
 
-//     name, "BlockBreak=0,BlockBreakAll=0,BlockIfElse=0,"
-//     "Brackets=Break,BracketsCloseHeaders=0,FStyle=,Fill=Tabs,"
-//     "FillCount=4,FillEmptyLines=0,FillForce=0,IndentBlocks=0,"
-//     "IndentBrackets=0,IndentCases=0,IndentClasses=1,IndentLabels=1,"
-//     "IndentNamespaces=1,IndentPreprocessors=0,IndentSwitches=1,"
-//     "KeepBlocks=1,KeepStatements=1,MaxStatement=40,"
-//     "MinConditional=-1,PadOperators=0,PadParenthesesIn=1,"
-//     "PadParenthesesOut=1,PadParenthesesUn=1,");
-
 void AStyleFormatter::loadStyle(const QString &content)
 {
-//     QStringList pairs = options.split(',', QString::SkipEmptyParts );
-//     QStringList::Iterator it;
-//     for ( it = pairs.begin(); it != pairs.end(); ++it ) {
-//         QStringList bits = (*it).split('=');
-//         m_options[bits[0]] = bits[1];
-//     }
-    m_options = KDevelop::ISourceFormatter::stringToOptionMap(content);
+    m_options = ISourceFormatter::stringToOptionMap(content);
     updateFormatter();
 }
 
 QString AStyleFormatter::saveStyle()
 {
-    return KDevelop::ISourceFormatter::optionMapToString(m_options);
-//     QMap<QString, QVariant>::const_iterator it = m_options.constBegin();
-//     for(; it != m_options.constEnd(); it++) {
-//         options += it.key();
-//         options += '=';
-//         options += it.value().toString();
-//         options += ',';
-//     }
-
-//     KConfigGroup group = config->group("AStyle");
-//     group.writeEntry(name, options);
-//     group.writeEntry("Extensions", m_extensions.join(","));
-//     group.sync();
-//     kDebug() << "Saving config to" << name << " : "<< options << endl;
+    return ISourceFormatter::optionMapToString(m_options);
 }
 
 void AStyleFormatter::setTabIndentation(int length, bool forceTabs)
@@ -440,7 +398,7 @@ void AStyleFormatter::setNamespaceIndent(bool on)
 void AStyleFormatter::setPreprocessorIndent(bool on)
 {
     m_options["IndentPreprocessors"] = on;
-    ASFormatter::setPreprocessorIndent(on);
+    ASFormatter::setPreprocDefineIndent(on);
 }
 
 void AStyleFormatter::setSwitchIndent(bool on)
@@ -474,14 +432,14 @@ void AStyleFormatter::setBracketFormatMode(astyle::BracketMode mode)
     case astyle::BREAK_MODE:
         m_options["Brackets"] = "Break";
         break;
-    case astyle::BDAC_MODE:
+    case astyle::LINUX_MODE:
         m_options["Brackets"] = "Linux";
         break;
     case astyle::STROUSTRUP_MODE:
         m_options["Brackets"] = "Stroustrup";
         break;
-    case astyle::HORSTMANN_MODE:
-        m_options["Brackets"] = "Horstmann";
+    case astyle::RUN_IN_MODE:
+        m_options["Brackets"] = "RunInMode";
         break;
     }
     ASFormatter::setBracketFormatMode(mode);
@@ -529,6 +487,11 @@ void AStyleFormatter::setParensInsidePaddingMode(bool mode)
     ASFormatter::setParensInsidePaddingMode(mode);
 }
 
+void AStyleFormatter::setParensHeaderPaddingMode(bool mode) {
+    m_options["PadParenthesesHeader"] = mode;
+    ASFormatter::setParensHeaderPaddingMode(mode);
+}
+
 void AStyleFormatter::setParensUnPaddingMode(bool state)
 {
     m_options["PadParenthesesUn"] = state;
@@ -550,16 +513,16 @@ void AStyleFormatter::setSingleStatementsMode(bool state)
 void AStyleFormatter::setPointerAlignment(astyle::PointerAlign alignment)
 {
     switch (alignment) {
-        case astyle::ALIGN_NONE:
+        case astyle::PTR_ALIGN_NONE:
             m_options["PointerAlign"] = "None";
             break;
-        case astyle::ALIGN_NAME:
+        case astyle::PTR_ALIGN_NAME:
             m_options["PointerAlign"] = "Name";
             break;
-        case astyle::ALIGN_MIDDLE:
+        case astyle::PTR_ALIGN_MIDDLE:
             m_options["PointerAlign"] = "Middle";
             break;
-        case astyle::ALIGN_TYPE:
+        case astyle::PTR_ALIGN_TYPE:
             m_options["PointerAlign"] = "Type";
             break;
     }
