@@ -21,6 +21,7 @@
 #define SIGNATUREASSISTANT_H
 
 #include "adaptsignatureaction.h"
+#include "clangprivateexport.h"
 
 #include <language/assistant/staticassistant.h>
 #include <language/duchain/identifier.h>
@@ -33,11 +34,7 @@ namespace KTextEditor {
 class View;
 }
 
-namespace KDevelop {
-class ParseJob;
-}
-
-class AdaptSignatureAssistant : public KDevelop::StaticAssistant
+class KDEVCLANGPRIVATE_EXPORT AdaptSignatureAssistant : public KDevelop::StaticAssistant
 {
     Q_OBJECT
 
@@ -45,8 +42,9 @@ public:
     AdaptSignatureAssistant(KDevelop::ILanguageSupport* supportedLanguage);
 
     QString title() const override;
-    void textChanged(KTextEditor::View* view, const KTextEditor::Range& invocationRange, const QString& removedText = QString()) override;
+    void textChanged(KTextEditor::Document* doc, const KTextEditor::Range& invocationRange, const QString& removedText = QString()) override;
     bool isUseful() const override;
+    KTextEditor::Range displayRange() const override;
 
 private:
     ///Compare @param newSignature to m_oldSignature and put differences in oldPositions
@@ -64,13 +62,14 @@ private:
     KDevelop::DeclarationId m_otherSideId;
     KDevelop::ReferencedTopDUContext m_otherSideTopContext;
     KDevelop::DUContextPointer m_otherSideContext;
+    KTextEditor::Cursor m_lastEditPosition;
     //old signature of the _other_side
     Signature m_oldSignature;
-    QUrl m_document;
+    QPointer<KTextEditor::Document> m_document;
     QPointer<KTextEditor::View> m_view;
 
 private slots:
-    void parseJobFinished(KDevelop::ParseJob*);
+    void updateReady(const KDevelop::IndexedString& document, const KDevelop::ReferencedTopDUContext& context) override;
     void reset();
 };
 
