@@ -96,6 +96,12 @@ CXCursor referencedCursor(CXCursor cursor)
 
 Identifier makeId(CXCursor cursor)
 {
+    if (CursorKindTraits::isClassTemplate(cursor.kind)) {
+        // TODO: how to handle functions here? We don't want to add the "real" function arguments here
+        //       and there does not seem to be an API to get the template arguments for non-specializations easily
+        // NOTE: using the QString overload of the Identifier ctor here, so that the template name gets parsed
+        return Identifier(ClangString(clang_getCursorDisplayName(cursor)).toString());
+    }
     return Identifier(ClangString(clang_getCursorSpelling(cursor)).toIndexed());
 }
 
@@ -894,7 +900,11 @@ CXChildVisitResult Visitor::dispatchCursor(CXCursor cursor, CXCursor parent)
 
     constexpr bool isClassMember = IsInClass == Decision::True;
     constexpr bool isDefinition = IsDefinition == Decision::True;
-    constexpr bool hasContext = CursorKindTraits::isFunction(CK) || (IsDefinition == Decision::True);
+    // always build a context for class templates and functions, otherwise we "leak"
+    // the function/template parameter declarations into the surrounding context,
+    // which can lead to interesting bugs, like https://bugs.kde.org/show_bug.cgi?id=368067
+    constexpr bool hasContext = isDefinition || CursorKindTraits::isFunction(CK) || CursorKindTraits::isClassTemplate(CK);
+
     return buildDeclaration<CK, typename DeclType<CK, isDefinition, isClassMember>::Type, hasContext>(cursor);
 }
 
