@@ -22,11 +22,14 @@
 #ifndef CLANGHELPERS_H
 #define CLANGHELPERS_H
 
-#include <clang-c/Index.h>
+#include "clangprivateexport.h"
+
 #include <language/duchain/duchainpointer.h>
 #include <language/duchain/topducontext.h>
 
-#include <duchain/clangduchainexport.h>
+#include <clang-c/Index.h>
+
+#include <functional>
 
 class ParseSession;
 class ClangIndex;
@@ -42,7 +45,7 @@ using IncludeFileContexts = QHash<CXFile, KDevelop::ReferencedTopDUContext>;
 
 namespace ClangHelpers {
 
-KDevelop::DeclarationPointer findDeclaration(CXSourceLocation cursor, const KDevelop::ReferencedTopDUContext& top);
+KDevelop::DeclarationPointer findDeclaration(CXSourceLocation cursor, KDevelop::QualifiedIdentifier id, const KDevelop::ReferencedTopDUContext& top);
 KDevelop::DeclarationPointer findDeclaration(CXCursor cursor, const IncludeFileContexts& includes);
 KDevelop::DeclarationPointer findDeclaration(CXType type, const IncludeFileContexts& includes);
 
@@ -62,7 +65,7 @@ KDevelop::RangeInRevision cursorSpellingNameRange(CXCursor cursor, const KDevelo
 /**
  * @returns all the Imports for each file in the @param tu
  */
-KDEVCLANGDUCHAIN_EXPORT Imports tuImports(CXTranslationUnit tu);
+KDEVCLANGPRIVATE_EXPORT Imports tuImports(CXTranslationUnit tu);
 
 /**
  * Recursively builds a duchain with the specified @param features for the
@@ -70,10 +73,10 @@ KDEVCLANGDUCHAIN_EXPORT Imports tuImports(CXTranslationUnit tu);
  * The resulting contexts are placed in @param includedFiles.
  * @returns the context created for @param file
  */
-KDEVCLANGDUCHAIN_EXPORT KDevelop::ReferencedTopDUContext buildDUChain(
+KDEVCLANGPRIVATE_EXPORT KDevelop::ReferencedTopDUContext buildDUChain(
     CXFile file, const Imports& imports, const ParseSession& session,
     KDevelop::TopDUContext::Features features, IncludeFileContexts& includedFiles,
-    ClangIndex* index = nullptr);
+    ClangIndex* index = nullptr, const std::function<bool()>& abortFunction = {});
 
 /**
  * @return List of possible header extensions used for definition/declaration fallback switching
@@ -88,12 +91,12 @@ QStringList sourceExtensions();
 /**
  * @return True if the given file @p path has the extension of a C++ source file
  */
-bool isSource(const QString& path);
+KDEVCLANGPRIVATE_EXPORT bool isSource(const QString& path);
 
 /**
  * @return True if the given file @p path has the extension of a C++ header file
  */
-bool isHeader(const QString& path);
+KDEVCLANGPRIVATE_EXPORT bool isHeader(const QString& path);
 
 }
 
