@@ -22,7 +22,8 @@
 #include "contextbuilder.h"
 #include "cppduchainexport.h"
 #include <language/duchain/builders/abstractusebuilder.h>
-#include <parsesession.h>
+
+class ParseSession;
 
 class UseBuilderBase : public KDevelop::AbstractUseBuilder<AST, NameAST, ContextBuilder> {
   public:
@@ -47,46 +48,46 @@ public:
    */
   void buildUses(AST *node);
 
-  QList<KSharedPtr<KDevelop::Problem> > problems() const;
+  QList<QExplicitlySharedDataPointer<KDevelop::Problem> > problems() const;
 
-  void addProblem(KSharedPtr<KDevelop::Problem> problem);
+  void addProblem(QExplicitlySharedDataPointer<KDevelop::Problem> problem);
   
   using UseBuilderBase::newUse;
 
 protected:
-  virtual void visitPrimaryExpression (PrimaryExpressionAST*);
-  virtual void visitMemInitializer(MemInitializerAST *);
+  virtual void visitPrimaryExpression (PrimaryExpressionAST*) override;
+  virtual void visitMemInitializer(MemInitializerAST *) override;
 
-  virtual void visitExpressionOrDeclarationStatement(ExpressionOrDeclarationStatementAST *) ;
-  virtual void visitExpressionStatement(ExpressionStatementAST *) ;
+  virtual void visitExpressionOrDeclarationStatement(ExpressionOrDeclarationStatementAST *) override ;
+  virtual void visitExpressionStatement(ExpressionStatementAST *) override ;
 
-  virtual void visitBinaryExpression(BinaryExpressionAST *) ;
-  virtual void visitCastExpression(CastExpressionAST *) ;
-  virtual void visitConditionalExpression(ConditionalExpressionAST *) ;
-  virtual void visitCppCastExpression(CppCastExpressionAST *) ;
+  virtual void visitBinaryExpression(BinaryExpressionAST *) override ;
+  virtual void visitCastExpression(CastExpressionAST *) override ;
+  virtual void visitConditionalExpression(ConditionalExpressionAST *) override ;
+  virtual void visitCppCastExpression(CppCastExpressionAST *) override ;
   //virtual void visitDeleteExpression(DeleteExpressionAST *) ;
   //virtual void visitIncrDecrExpression(IncrDecrExpressionAST *) ;
-  virtual void visitNewExpression(NewExpressionAST *) ;
-  virtual void visitPostfixExpression(PostfixExpressionAST *) ;
-  virtual void visitSizeofExpression(SizeofExpressionAST *) ;
-  virtual void visitSubscriptExpression(SubscriptExpressionAST *) ;
+  virtual void visitNewExpression(NewExpressionAST *) override ;
+  virtual void visitPostfixExpression(PostfixExpressionAST *) override ;
+  virtual void visitSizeofExpression(SizeofExpressionAST *) override ;
+  virtual void visitSubscriptExpression(SubscriptExpressionAST *) override ;
   //virtual void visitThrowExpression(ThrowExpressionAST *) ;
-  virtual void visitUnaryExpression(UnaryExpressionAST *) ;
-  virtual void visitBaseSpecifier(BaseSpecifierAST *);
+  virtual void visitUnaryExpression(UnaryExpressionAST *) override ;
+  virtual void visitBaseSpecifier(BaseSpecifierAST *) override;
 
 //   virtual void visitBaseSpecifier(BaseSpecifierAST* node);
-  virtual void visitElaboratedTypeSpecifier(ElaboratedTypeSpecifierAST *);
-  virtual void visitSimpleTypeSpecifier(SimpleTypeSpecifierAST* node);
-  virtual void visitSimpleDeclaration(SimpleDeclarationAST* );  
-  virtual void visitCondition(ConditionAST *node);
-  virtual void visitDeclarator(DeclaratorAST* node);
-  virtual void visitUsing(UsingAST *);
-  void visitTypeId(TypeIdAST* type_id);
-  virtual void visitClassSpecifier(ClassSpecifierAST* node);
-  virtual void visitUsingDirective(UsingDirectiveAST* node);
-  virtual void visitNamespaceAliasDefinition(NamespaceAliasDefinitionAST* node);
-  virtual void visitTypeIDOperator(TypeIDOperatorAST* node);
-  virtual void visitQPropertyDeclaration(QPropertyDeclarationAST* );
+  virtual void visitElaboratedTypeSpecifier(ElaboratedTypeSpecifierAST *) override;
+  virtual void visitSimpleTypeSpecifier(SimpleTypeSpecifierAST* node) override;
+  virtual void visitSimpleDeclaration(SimpleDeclarationAST* ) override;  
+  virtual void visitCondition(ConditionAST *node) override;
+  virtual void visitDeclarator(DeclaratorAST* node) override;
+  virtual void visitUsing(UsingAST *) override;
+  void visitTypeId(TypeIdAST* type_id) override;
+  virtual void visitClassSpecifier(ClassSpecifierAST* node) override;
+  virtual void visitUsingDirective(UsingDirectiveAST* node) override;
+  virtual void visitNamespaceAliasDefinition(NamespaceAliasDefinitionAST* node) override;
+  virtual void visitTypeIDOperator(TypeIDOperatorAST* node) override;
+  virtual void visitQPropertyDeclaration(QPropertyDeclarationAST* ) override;
 
 private:
   void buildUsesForName(NameAST* name);
@@ -99,7 +100,7 @@ private:
   QStack<QVector<int> > m_skippedUses;
   QStack<DUContext*> m_contexts;
 
-  QList< KSharedPtr< KDevelop::Problem > > m_problems;
+  QList< QExplicitlySharedDataPointer< KDevelop::Problem > > m_problems;
 };
 
 #endif // USEBUILDER_H
