@@ -74,7 +74,7 @@ static ConfigEntry findConfigForItem(QList<ConfigEntry> paths, const KDevelop::P
                 }
             }
 
-            if (ret.parserArguments.isEmpty() || targetDirectory.segments().size() > closestPath.segments().size()) {
+            if (targetDirectory.segments().size() > closestPath.segments().size()) {
                 ret.parserArguments = entry.parserArguments;
                 closestPath = targetDirectory;
             }
@@ -82,7 +82,8 @@ static ConfigEntry findConfigForItem(QList<ConfigEntry> paths, const KDevelop::P
     }
     ret.includes.removeDuplicates();
 
-    Q_ASSERT(!ret.parserArguments.isEmpty());
+    Q_ASSERT(!ret.parserArguments.cppArguments.isEmpty());
+    Q_ASSERT(!ret.parserArguments.cArguments.isEmpty());
 
     return ret;
 }
@@ -144,6 +145,8 @@ Defines DefinesAndIncludesManager::defines( ProjectBaseItem* item, Type type  )
         merge(&defines, findConfigForItem(m_settings->readPaths(cfg), item).defines);
     }
 
+    merge(&defines, m_noProjectIPM->includesAndDefines(item->path().path()).second);
+
     return defines;
 }
 
@@ -171,11 +174,23 @@ Path::List DefinesAndIncludesManager::includes( ProjectBaseItem* item, Type type
     }
 
     for (auto provider : m_providers) {
-        if (provider->type() & type) {
-            includes += provider->includes(item);
+        if ( !(provider->type() & type) ) {
+            continue;
         }
+        auto newItems = provider->includes(item);
+        if ( provider->type() & DefinesAndIncludesManager::CompilerSpecific ) {
+            // If an item occurs in the "compiler specific" list, but was previously supplied
+            // in the user include path list already, remove it from there.
+            // Re-ordering the system include paths causes confusion in some cases.
+            Q_FOREACH (const auto& x, newItems ) {
+                includes.removeAll(x);
+            }
+        }
+        includes += newItems;
     }
 
+    includes += m_noProjectIPM->includesAndDefines(item->path().path()).first;
+
     return includes;
 }
 
@@ -200,14 +215,17 @@ void DefinesAndIncludesManager::registerProvider(IDefinesAndIncludesManager::Pro
     m_providers.push_back(provider);
 }
 
-Defines DefinesAndIncludesManager::defines(const QString&) const
+Defines DefinesAndIncludesManager::defines(const QString& path) const
 {
-    return m_settings->provider()->defines(nullptr);
+    Defines ret = m_settings->provider()->defines(nullptr);
+    merge(&ret, m_noProjectIPM->includesAndDefines(path).second);
+    return ret;
 }
 
 Path::List DefinesAndIncludesManager::includes(const QString& path) const
 {
-    return m_settings->provider()->includes(nullptr) + m_noProjectIPM->includes(path);
+    return m_settings->provider()->includes(nullptr) 
+           + m_noProjectIPM->includesAndDefines(path).first;
 }
 
 void DefinesAndIncludesManager::openConfigurationDialog(const QString& pathToFile)
@@ -241,6 +259,8 @@ Defines DefinesAndIncludesManager::definesInBackground(const QString& path) cons
         }
     }
 
+    merge(&defines, m_noProjectIPM->includesAndDefines(path).second);
+
     return defines;
 }
 
@@ -267,14 +287,22 @@ void DefinesAndIncludesManager::registerBackgroundProvider(IDefinesAndIncludesMa
 
 QString DefinesAndIncludesManager::parserArguments(KDevelop::ProjectBaseItem* item) const
 {
-    if(!item){
-        return m_settings->defaultParserArguments();
-    }
+    Q_ASSERT(item);
 
     Q_ASSERT(QThread::currentThread() == qApp->thread());
 
     auto cfg = item->project()->projectConfiguration().data();
-    return findConfigForItem(m_settings->readPaths(cfg), item).parserArguments;
+    const auto arguments = findConfigForItem(m_settings->readPaths(cfg), item).parserArguments;
+    auto languageType = Utils::languageType(item->path(), arguments.parseAmbiguousAsCPP);
+
+    return languageType == Utils::C ? arguments.cArguments : arguments.cppArguments;
+}
+
+QString DefinesAndIncludesManager::parserArguments(const QString& path) const
+{
+    const auto args = m_settings->defaultParserArguments();
+    auto languageType = Utils::languageType(Path(path));
+    return languageType == Utils::C ? args.cArguments : args.cppArguments;
 }
 
 int DefinesAndIncludesManager::perProjectConfigPages() const
