@@ -46,7 +46,7 @@ QTEST_MAIN(TestFiles)
 
 void TestFiles::initTestCase()
 {
-  AutoTestShell::init();
+  AutoTestShell::init({"kdevqmljslanguagesupport"});
   TestCore::initialize(KDevelop::Core::NoUi);
   DUChain::self()->disablePersistentStorage();
   Core::self()->languageController()->backgroundParser()->setDelay(0);
@@ -134,6 +134,7 @@ void TestFiles::parseAndCheck(const QString& fileName, bool check)
     if (!QTest::currentDataTag() || strcmp("failparse.js", QTest::currentDataTag()) != 0) {
         QEXPECT_FAIL("plugins.qml", "not working properly yet", Continue);
         QEXPECT_FAIL("qrc_import.qml", "just making sure it does not crash", Continue);
+        QEXPECT_FAIL("dynamicObjectProperties.2.qml", "just making sure it does not crash", Continue);
         QVERIFY(top->problems().isEmpty());
     }
   }
